@@ -4,7 +4,7 @@
 %  Copyright (c) 1998-2015 Paulo Moura <pmoura@logtalk.org>
 %
 %  Adapter file for CxProlog 0.97.7 or a later version
-%  Last updated on December 20, 2014
+%  Last updated on February 16, 2015
 %
 %  This program is free software: you can redistribute it and/or modify
 %  it under the terms of the GNU General Public License as published by
@@ -51,37 +51,13 @@
 '$lgt_iso_predicate'(subsumes_term(_, _)).
 
 subsumes_term(General, Specific) :-
-	term_variables(Specific, Vars),
-	'$lgt_cx_subsumes_term'(General, Specific, Vars).
+	\+ \+ '$lgt_cx_subsumes'(General, Specific).
 
-'$lgt_cx_subsumes_term'(General, Specific, Vars) :-
-	var(General),
-	!,
-	(	'$lgt_cx_var_member_chk'(General, Vars) ->
-		General == Specific
-	;	\+ General \= Specific
-	).
-
-'$lgt_cx_subsumes_term'(General, Specific, Vars) :-
-	nonvar(Specific),
-	functor(General, Functor, Arity),
-	functor(Specific, Functor, Arity),
-	'$lgt_cx_subsumes_term'(Arity, General, Specific, Vars).
-
-'$lgt_cx_subsumes_term'(0, _, _, _) :-
-	!.
-'$lgt_cx_subsumes_term'(N, General, Specific, Vars) :-
-	arg(N, General,  GenArg),
-	arg(N, Specific, SpeArg),
-	'$lgt_cx_subsumes_term'(GenArg, SpeArg, Vars),
-	M is N-1, !,
-	'$lgt_cx_subsumes_term'(M, General, Specific, Vars).
-
-'$lgt_cx_var_member_chk'(Var, [Head| Tail]) :-
-	(	Var == Head ->
-		true
-	;	'$lgt_cx_var_member_chk'(Var, Tail)
-	).
+'$lgt_cx_subsumes'(General, Specific) :-
+	term_variables(Specific, Vars1),
+	unify_with_occurs_check(General, Specific),
+	term_variables(Vars1, Vars2),
+	Vars1 == Vars2.
 
 
 
@@ -371,7 +347,7 @@ setup_call_cleanup(Setup, Call, Cleanup) :-
 % '$lgt_compile_prolog_code'(+atom, +atom, +list)
 %
 % compile to disk a Prolog file, resulting from a
-% Logtalk source file, given a list of options
+% Logtalk source file, given a list of flags
 
 '$lgt_compile_prolog_code'(_, _, _).
 
@@ -379,7 +355,7 @@ setup_call_cleanup(Setup, Call, Cleanup) :-
 % '$lgt_load_prolog_code'(+atom, +atom, +list)
 %
 % compile and load a Prolog file, resulting from a
-% Logtalk source file, given a list of options
+% Logtalk source file, given a list of flags
 
 '$lgt_load_prolog_code'(File, _, [encoding(Encoding)]) :-
 	!,
@@ -410,7 +386,7 @@ setup_call_cleanup(Setup, Call, Cleanup) :-
 
 % '$lgt_startup_directory'(-atom)
 %
-% returns the Logtalk startup directory 
+% returns the Logtalk startup directory
 
 '$lgt_startup_directory'(Directory) :-
 	(	os_env('LOGTALK_STARTUP_DIRECTORY', Directory) ->
@@ -482,44 +458,6 @@ setup_call_cleanup(Setup, Call, Cleanup) :-
 
 
 
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  time and date predicates
-%
-%  if your Prolog compiler does not provide access to the operating system 
-%  time and date just write dummy definitions
-%
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-
-
-% '$lgt_current_date'(?integer, ?integer, ?integer)
-
-'$lgt_current_date'(2006, 6, 25).
-
-
-% '$lgt_current_time'(?integer, ?integer, ?integer)
-
-'$lgt_current_time'(10, 39, 12).
-
-
-
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  timing predicate
-%
-%  if your Prolog compiler does not provide access to a timing predicate 
-%  just write a dummy definition
-%
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-
-
-% '$lgt_cpu_time'(-Seconds)
-
-'$lgt_cpu_time'(Seconds) :-
-	Seconds is cputime.
-
-
-
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  getting stream current line number
