@@ -4,7 +4,7 @@
 %  Copyright (c) 1998-2015 Paulo Moura <pmoura@logtalk.org>
 %
 %  Adapter file for GNU Prolog 1.4.2 (and later versions)
-%  Last updated on December 20, 2014
+%  Last updated on February 16, 2015
 %
 %  This program is free software: you can redistribute it and/or modify
 %  it under the terms of the GNU General Public License as published by
@@ -210,7 +210,11 @@ setup_call_cleanup(_, _, _) :-
 '$lgt_prolog_feature'(encoding_directive, unsupported).
 '$lgt_prolog_feature'(tabling, unsupported).
 '$lgt_prolog_feature'(threads, unsupported).
-'$lgt_prolog_feature'(modules, unsupported).
+:- if(predicate_property(current_module(_), built_in)).
+	'$lgt_prolog_feature'(modules, supported).
+:- else.
+	'$lgt_prolog_feature'(modules, unsupported).
+:- endif.
 '$lgt_prolog_feature'(coinduction, unsupported).
 
 
@@ -342,7 +346,7 @@ setup_call_cleanup(_, _, _) :-
 % '$lgt_compile_prolog_code'(+atom, +atom, +list)
 %
 % compile to disk a Prolog file, resulting from a
-% Logtalk source file, given a list of options
+% Logtalk source file, given a list of flags
 
 '$lgt_compile_prolog_code'(_, _, _).
 
@@ -350,7 +354,7 @@ setup_call_cleanup(_, _, _) :-
 % '$lgt_load_prolog_code'(+atom, +atom, +list)
 %
 % compile and load a Prolog file, resulting from a
-% Logtalk source file, given a list of options
+% Logtalk source file, given a list of flags
 
 '$lgt_load_prolog_code'(File, _, _) :-
 	consult(File).
@@ -374,7 +378,7 @@ setup_call_cleanup(_, _, _) :-
 
 % '$lgt_startup_directory'(-atom)
 %
-% returns the Logtalk startup directory 
+% returns the Logtalk startup directory
 
 '$lgt_startup_directory'(Directory) :-
 	(	environ('LOGTALK_STARTUP_DIRECTORY', Directory) ->
@@ -416,47 +420,6 @@ setup_call_cleanup(_, _, _) :-
 
 
 
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  time and date predicates
-%
-%  if your Prolog compiler does not provide access to the operating system 
-%  time and date just write dummy definitions
-%
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-
-
-% '$lgt_current_date'(?integer, ?integer, ?integer)
-
-'$lgt_current_date'(Year, Month, Day) :-
-	date_time(dt(Year, Month, Day, _, _, _)).
-
-
-% '$lgt_current_time'(?integer, ?integer, ?integer)
-
-'$lgt_current_time'(Hours, Minutes, Seconds) :-
-	date_time(dt(_, _, _, Hours, Minutes, Seconds)).
-
-
-
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  timing predicate
-%
-%  if your Prolog compiler does not provide access to a timing predicate 
-%  just write a dummy definition
-%
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-
-
-% '$lgt_cpu_time'(-Seconds)
-
-'$lgt_cpu_time'(Seconds) :-
-	cpu_time(Miliseconds),
-	Seconds is Miliseconds / 1000.
-
-
-
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  getting stream current line number
@@ -729,7 +692,11 @@ with_mutex(_, _) :- fail.
 
 % '$lgt_user_module_qualification'(@callable, -callable)
 
-'$lgt_user_module_qualification'(Goal, Goal).
+:- if(predicate_property(current_module(_), built_in)).
+	'$lgt_user_module_qualification'(Goal, ':'(user,Goal)).
+:- else.
+	'$lgt_user_module_qualification'(Goal, Goal).
+:- endif.
 
 
 
