@@ -4,7 +4,7 @@
 %  Copyright (c) 1998-2015 Paulo Moura <pmoura@logtalk.org>
 %
 %  Adapter file for Qu-Prolog 9.0 and later versions
-%  Last updated on December 20, 2014
+%  Last updated on February 16, 2015
 %
 %  This program is free software: you can redistribute it and/or modify
 %  it under the terms of the GNU General Public License as published by
@@ -54,37 +54,13 @@ sub_atom(Atom, Before, Length, After, SubAtom) :-
 	string_to_atom(SubString, SubAtom).
 
 subsumes_term(General, Specific) :-
-	collect_vars(Specific, Vars),
-	'$lgt_qp_subsumes_term'(General, Specific, Vars).
+	\+ \+ '$lgt_qp_subsumes'(General, Specific).
 
-'$lgt_qp_subsumes_term'(General, Specific, Vars) :-
-	var(General),
-	!,
-	(	'$lgt_qp_var_member_chk'(General, Vars) ->
-		General == Specific
-	;	\+ General \= Specific
-	).
-
-'$lgt_qp_subsumes_term'(General, Specific, Vars) :-
-	nonvar(Specific),
-	functor(General, Functor, Arity),
-	functor(Specific, Functor, Arity),
-	'$lgt_qp_subsumes_term'(Arity, General, Specific, Vars).
-
-'$lgt_qp_subsumes_term'(0, _, _, _) :-
-	!.
-'$lgt_qp_subsumes_term'(N, General, Specific, Vars) :-
-	arg(N, General,  GenArg),
-	arg(N, Specific, SpeArg),
-	'$lgt_qp_subsumes_term'(GenArg, SpeArg, Vars),
-	M is N-1, !,
-	'$lgt_qp_subsumes_term'(M, General, Specific, Vars).
-
-'$lgt_qp_var_member_chk'(Var, [Head| Tail]) :-
-	(	Var == Head ->
-		true
-	;	'$lgt_qp_var_member_chk'(Var, Tail)
-	).
+'$lgt_qp_subsumes'(General, Specific) :-
+	collect_vars(Specific, Vars1),
+	unify_with_occurs_check(General, Specific),
+	collect_vars(Vars1, Vars2),
+	Vars1 == Vars2.
 
 term_variables(Term, Variables) :-
 	collect_vars(Term, Variables).
@@ -411,7 +387,7 @@ format(Format, Arguments) :-
 % '$lgt_compile_prolog_code'(+atom, +atom, +list)
 %
 % compile to disk a Prolog file, resulting from a
-% Logtalk source file, given a list of options
+% Logtalk source file, given a list of flags
 
 '$lgt_compile_prolog_code'(File, _, Options) :-
 	fcompile(File, Options).
@@ -420,7 +396,7 @@ format(Format, Arguments) :-
 % '$lgt_load_prolog_code'(+atom, +atom, +list)
 %
 % compile and load a Prolog file, resulting from a
-% Logtalk source file, given a list of options
+% Logtalk source file, given a list of flags
 
 '$lgt_load_prolog_code'(File, _, _) :-
 	'$lgt_file_extension'(object, Extension),
@@ -446,7 +422,7 @@ format(Format, Arguments) :-
 
 % '$lgt_startup_directory'(-atom)
 %
-% returns the Logtalk startup directory 
+% returns the Logtalk startup directory
 
 '$lgt_startup_directory'(Directory) :-
 	getenv('LOGTALK_STARTUP_DIRECTORY', Directory).
@@ -515,51 +491,6 @@ format(Format, Arguments) :-
 
 
 
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  time and date predicates
-%
-%  if your Prolog compiler does not provide access to the operating system 
-%  time and date just write dummy definitions
-%
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-
-
-% '$lgt_current_date'(?integer, ?integer, ?integer)
-
-'$lgt_current_date'(Year, Month, Day) :-
-	realtime(Time),
-	localtime(Time, time(Year2, Month2, Day, _, _, _, _)),
-	Year is 1900 + Year2,
-	Month is Month2 + 1.
-
-
-% '$lgt_current_time'(?integer, ?integer, ?integer)
-
-'$lgt_current_time'(Hours, Minutes, Seconds) :-
-	realtime(Time),
-	localtime(Time, time(_, _, _, Hours, Minutes, Seconds, _)).
-
-
-
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  timing predicate
-%
-%  if your Prolog compiler does not provide access to a timing predicate 
-%  just write a dummy definition
-%
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-
-
-% '$lgt_cpu_time'(-Seconds)
-
-'$lgt_cpu_time'(Seconds) :-
-	statistics(runtime, [Start,_]),
-	Seconds is Start/1000.
-
-
-
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  getting stream current line number
