@@ -6,7 +6,7 @@
 ##   Copyright (c) 1998-2015 Paulo Moura <pmoura@logtalk.org>
 ## 
 ##   Release build script
-##   Last updated on September 22, 2013
+##   Last updated on January 15, 2015
 ## 
 ##   This program is free software: you can redistribute it and/or modify
 ##   it under the terms of the GNU General Public License as published by
@@ -42,8 +42,15 @@ directory=`PWD`
 cd logtalk-$version
 chmod a+x scripts/cleandist.sh
 scripts/cleandist.sh
-
 cd ..
+
+cp -R logtalk-$version/scripts/pack pack-$version
+cp -R logtalk-$version pack-$version/logtalk
+cd pack-$version
+tar zcvf logtalk-$version.tgz logtalk
+mv logtalk-$version.tgz ..
+cd ..
+
 cp -R logtalk-$version/manuals logtalk-manuals-$version
 tar -czf logtalk-manuals-$version.tgz logtalk-manuals-$version
 tar -cjf logtalk-$version.tar.bz2 logtalk-$version
@@ -90,7 +97,6 @@ sudo port clean logtalk
 sudo port destroot logtalk
 sudo port pkg logtalk
 cp -R work/logtalk-$version.pkg $directory
-zip -r $directory/logtalk-$version.pkg.zip $directory/logtalk-$version.pkg
 sudo port clean logtalk
 
 cd $directory
